from aspen import renderers
from aspen._tornado.template import Loader, Template


class Renderer(renderers.Renderer):

    def compile(self, filepath, raw):
        loader = self.meta
        return Template(raw, filepath, loader, compress_whitespace=False)

    def render_content(self, context):
        return self.compiled.generate(**context)


class Factory(renderers.Factory):

    Renderer = Renderer

    def compile_meta(self, configuration):
        bases_dir = configuration.project_root
        if bases_dir is None:
            loader = None
        else:
            loader = Loader(bases_dir)
        return loader



"""
Aspen's Auth modules.

Currently:

    * cookie - Cookie Auth
	* httpbasic - HTTP BASIC Auth
	* httpdigest - HTTP DIGEST Auth

"""
from aspen.utils import typecheck


class BaseUser(object):

    def __init__(self, token):
        typecheck(token, (unicode, None))
        self.token = token

    @property
    def ANON(self):
        return self.token is None

User = BaseUser
